lastModified

# XMLRésuméLibrary: User Guide

label | Element Reference | legalnotice

## Name

lastModified — Information about when a résumé was last modified

## Synopsis

### Content Model

    (date)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `lastModified` element contains the date that a résumé was last updated.

### Parents

`lastModified` may be contained in these elements: `resume`

## Examples

    <lastModified>
      <date>
        <dayOfMonth>4</dayOfMonth>
        <month>July</month>
        <year>1796</year>
      </date>
    </lastModified>

label | Element Reference | legalnotice